==> task-0.0.3-sources.jar: com/xujl/task/RxHandler.java <==
package com.xujl.task;

import android.os.Handler;
import android.os.Looper;
import android.os.Message;

/**
 * <pre>
 *     @author : xujl
 *     e-mail : 597355068@qq.com
 *     time   : 2018/7/23
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class RxHandler extends Handler {
    private static final String TAG = "RxHandler";

    static RxHandler getInstance () {
        return Holder.RX_HANDLER;
    }

    private RxHandler () {
        super(Looper.getMainLooper());
    }

    @Override
    public void handleMessage (Message msg) {
        super.handleMessage(msg);
        final Object obj = msg.obj;
        if (obj == null || !(obj instanceof RxMessage)) {
            Logger.d(TAG, "Task:  Message isNot Task");
            return;
        }
        RxMessage rxMessage = (RxMessage) obj;
        final Task task = rxMessage.getTask();
        if (task == null) {
            Logger.d(TAG, "Task:  task.isDestroy");
            return;
        }
        long taskId = task.getTaskId();
        try {
            switch (msg.what) {
                case Emitter.ERROR:
                    Logger.d(TAG, "Task--" + taskId + ":Emitter.ERROR");
                    task.onError((Exception) rxMessage.getObj());
                    break;
                case Emitter.NEXT:
                    Logger.d(TAG, "Task--" + taskId + ":Emitter.NEXT");
                    task.onNext(rxMessage.getObj());
                    break;
                case Emitter.UI:
                    Logger.d(TAG, "Task--" + taskId + ":Emitter.UI");
                    task.onlyRunUiTask();
                    break;
                case Emitter.FINISH:
                    Logger.d(TAG, "Task--" + taskId + ":Emitter.FINISH");
                    task.onFinished();
                    break;
                default:
                    break;
            }
        } catch (Exception e) {
            Logger.e(TAG, e);
        }

    }

    private static class Holder {
        private static final RxHandler RX_HANDLER = new RxHandler();
    }
}

==> task-1.0.0-sources.jar: com/xujl/task/RxHandler.java <==
package com.xujl.task;

import android.os.Handler;
import android.os.Looper;
import android.os.Message;

/**
 * <pre>
 *     @author : xujl
 *     e-mail : 597355068@qq.com
 *     time   : 2018/7/23
 *     desc   :
 *     version: 1.0
 * </pre>
 */
class RxHandler extends Handler {
    private static final String TAG = "RxHandler";

    static RxHandler getInstance () {
        return Holder.RX_HANDLER;
    }

    private RxHandler () {
        super(Looper.getMainLooper());
    }

    @Override
    public void handleMessage (Message msg) {
        super.handleMessage(msg);
        final Object obj = msg.obj;
        if (obj == null || !(obj instanceof RxMessage)) {
            Logger.d(TAG, "Task:  Message isNot Task");
            return;
        }
        RxMessage rxMessage = (RxMessage) obj;
        final Task task = rxMessage.getTask();
        if (task == null) {
            Logger.d(TAG, "Task:  task.isDestroy");
            return;
        }
        long taskId = task.getTaskId();
        try {
            switch (msg.what) {
                case Emitter.ERROR:
                    final Exception exception = (Exception) rxMessage.getObj();
                    Logger.d(TAG, "Task--" + taskId + ":Emitter.ERROR:" + exception.getMessage());
                    task.onError(exception);
                    break;
                case Emitter.NEXT:
                    if (rxMessage.getObj() != null) {
                        Logger.d(TAG, "Task--" + taskId + ":Emitter.ObjNEXT");
                        task.onObjNext(rxMessage.getObjCode(), rxMessage.getObj());
                    } else {
                        Logger.d(TAG, "Task--" + taskId + ":Emitter.NEXT");
                        task.onNext(rxMessage.getData());
                    }
                    break;
                case Emitter.UI:
                    Logger.d(TAG, "Task--" + taskId + ":Emitter.UI");
                    task.onlyRunUiTask();
                    break;
                case Emitter.FINISH:
                    Logger.d(TAG, "Task--" + taskId + ":Emitter.FINISH");
                    task.onFinished();
                    break;
                default:
                    break;
            }
        } catch (Exception e) {
            Logger.e(TAG, "RxTask严重错误：" + e);
        }

    }

    private static class Holder {
        private static final RxHandler RX_HANDLER = new RxHandler();
    }
}
